==> gulp-babili-0.0.0.tgz: package/lib/index.js <==
"use strict";

var babelCore = require("babel-core");
var through2 = require("through2");
var gutil = require("gulp-util");
var applySourceMap = require("vinyl-sourcemaps-apply");
var babiliPreset = require("babel-preset-babili");

var PluginError = gutil.PluginError;


var NAME = "gulp-babili";

module.exports = gulpBabili;

function gulpBabili() {
  var _opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var opts = Object.assign({}, _opts);

  return through2.obj(function (file, enc, callback) {
    if (file.isNull()) {
      return callback(null, file);
    }

    if (file.isStream()) {
      return callback(new PluginError(NAME, "Streaming not supported"));
    }

    var babel = babelCore;
    var babili = babiliPreset;

    if (opts.babel) {
      babel = opts.babel;
      delete opts.babel;
    }
    if (opts.babili) {
      babili = opts.babili;
      delete opts.babili;
    }

    var commentsRegex = typeof opts.comments === "undefined" ? /@preserve|@license/ : opts.comments;

    var inputSourceMap = void 0;
    if (file.sourceMap && file.sourceMap.mappings) {
      inputSourceMap = file.sourceMap;
    }

    var babelOpts = {
      minified: true,
      babelrc: false,
      ast: false,

      /* preset */
      presets: [[babili, opts]],

      /* sourcemaps */
      sourceMaps: true,
      inputSourceMap,

      /* remove comments */
      shouldPrintComment(contents) {
        return shouldPrintComment(contents, commentsRegex);
      },

      /* file */
      filename: file.path,
      filenameRelative: file.relative
    };

    var _transform = transform({
      babel,
      input: file.contents.toString(),
      babelOpts
    }),
        result = _transform.result,
        success = _transform.success,
        error = _transform.error;

    if (success) {
      file.contents = new Buffer(result.code);
      applySourceMap(file, result.map);
      return callback(null, file);
    }

    callback(error);
  });
}

function transform(_ref) {
  var babel = _ref.babel,
      input = _ref.input,
      babelOpts = _ref.babelOpts;

  try {
    return {
      success: true,
      result: babel.transform(input, babelOpts)
    };
  } catch (e) {
    return {
      success: false,
      error: e
    };
  }
}

function shouldPrintComment(contents, predicate) {
  switch (typeof predicate) {
    case "function":
      return predicate(contents);
    case "object":
      return predicate.test(contents);
    default:
      return !!predicate;
  }
}

==> gulp-babili-0.1.4.tgz: package/lib/index.js <==
"use strict";

var babelCore = require("babel-core");
var through2 = require("through2");
var gutil = require("gulp-util");
var applySourceMap = require("vinyl-sourcemaps-apply");
var babiliPreset = require("babel-preset-babili");

var PluginError = gutil.PluginError;


var NAME = "gulp-babili";

module.exports = gulpBabili;

function gulpBabili() {
  var babiliOpts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref$babel = _ref.babel,
      babel = _ref$babel === undefined ? babelCore : _ref$babel,
      _ref$babili = _ref.babili,
      babili = _ref$babili === undefined ? babiliPreset : _ref$babili,
      _ref$comments = _ref.comments,
      comments = _ref$comments === undefined ? /preserve|licen(s|c)e/ : _ref$comments;

  return through2.obj(function (file, enc, callback) {
    if (file.isNull()) {
      return callback(null, file);
    }

    if (file.isStream()) {
      return callback(new PluginError(NAME, "Streaming not supported"));
    }

    var inputSourceMap = void 0;
    if (file.sourceMap && file.sourceMap.mappings) {
      inputSourceMap = file.sourceMap;
    }

    var babelOpts = {
      minified: true,
      babelrc: false,
      ast: false,

      /* preset */
      presets: [[babili, babiliOpts]],

      /* sourcemaps */
      sourceMaps: !!file.sourceMap,
      inputSourceMap,

      shouldPrintComment(contents) {
        return shouldPrintComment(contents, comments);
      },

      /* file */
      filename: file.path,
      filenameRelative: file.relative
    };

    var _transform = transform({
      babel,
      input: file.contents.toString(),
      babelOpts
    }),
        result = _transform.result,
        success = _transform.success,
        error = _transform.error;

    if (success) {
      file.contents = new Buffer(result.code);
      if (file.sourceMap) {
        applySourceMap(file, result.map);
      }
      return callback(null, file);
    }

    callback(error);
  });
}

function transform(_ref2) {
  var babel = _ref2.babel,
      input = _ref2.input,
      babelOpts = _ref2.babelOpts;

  try {
    return {
      success: true,
      result: babel.transform(input, babelOpts)
    };
  } catch (e) {
    return {
      success: false,
      error: e
    };
  }
}

function shouldPrintComment(contents, predicate) {
  switch (typeof predicate) {
    case "function":
      return predicate(contents);
    case "object":
      return predicate.test(contents);
    default:
      return !!predicate;
  }
}
